==> chromium_108.0.5359.124.orig.tar.xz: chromium-108.0.5359.124/ash/webui/personalization_app/resources/js/wallpaper/wallpaper_state.ts <==
// Copyright 2021 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import {FilePath} from 'chrome://resources/mojo/mojo/public/mojom/base/file_path.mojom-webui.js';
import {Url} from 'chrome://resources/mojo/url/mojom/url.mojom-webui.js';

import {CurrentWallpaper, GooglePhotosAlbum, GooglePhotosEnablementState, GooglePhotosPhoto, WallpaperCollection, WallpaperImage} from '../personalization_app.mojom-webui.js';

import {DefaultImageSymbol, DisplayableImage, kDefaultImageSymbol} from './constants.js';

/**
 * Stores collections and images from backdrop server.
 * |images| is a mapping of collection id to the list of images.
 */
export interface BackdropState {
  collections: WallpaperCollection[]|null;
  images: Record<WallpaperCollection['id'], WallpaperImage[]|null>;
}

/**
 * Stores Google Photos state.
 * |enabled| is whether the user is allowed to access Google Photos. It is
 * undefined only until it has been initialized.
 * |albums| is the list of Google Photos albums. It is undefined only until it
 * has been initialized, then either null (in error state) or a valid Array.
 * |photos| is the list of Google Photos photos. It is undefined only until it
 * has been initialized, then either null (in error state) or a valid Array.
 * |photosByAlbumId| is the list of Google Photos photos keyed by album id. The
 * list of photos for a given album id is undefined only until is has been
 * initialized, then either null (in error state) or a valid Array.
 */
export interface GooglePhotosState {
  enabled: GooglePhotosEnablementState|undefined;
  albums: GooglePhotosAlbum[]|null|undefined;
  photos: GooglePhotosPhoto[]|null|undefined;
  photosByAlbumId: Record<string, GooglePhotosPhoto[]|null|undefined>;
  resumeTokens: {
    albums: string|null,
    photos: string|null,
    photosByAlbumId: Record<string, string|null>,
  };
}

/**
 * Stores loading state of various components of the app.
 * |images| is a mapping of collection id to loading state.
 * |local| stores data just for local images on disk.
 * |local.data| stores a mapping of FilePath.path string to loading state.
 *
 * |selected| is a boolean representing the loading state of current wallpaper
 * information. This gets complicated when a user rapidly selects multiple
 * wallpaper images, or picks a new daily refresh wallpaper. This becomes
 * false when a new CurrentWallpaper object is received and the |setImage|
 * counter is at 0.
 *
 * |setImage| is a number representing the number of concurrent requests to set
 * current wallpaper information. This can be more than 1 in case a user rapidly
 * selects multiple wallpaper options.
 *
 * |googlePhotos| stores loading state of Google Photos data.
 */
export interface LoadingState {
  collections: boolean;
  images: Record<WallpaperCollection['id'], boolean>;
  local: {
    images: boolean,
    data: Record<FilePath['path']|DefaultImageSymbol, boolean>,
  };
  refreshWallpaper: boolean;
  selected: boolean;
  setImage: number;
  googlePhotos: {
    enabled: boolean,
    albums: boolean,
    photos: boolean,
    photosByAlbumId: Record<string, boolean>,
  };
}

/**
 * |images| stores the list of images on local disk. The image in index 0 may be
 * a special case for default image thumbnail.
 * |data| stores a mapping of image.path to a thumbnail data url. There is also
 * a special key to represent the default image thumbnail.
 */
export interface LocalState {
  images: Array<FilePath|DefaultImageSymbol>|null;
  data: Record<FilePath['path']|DefaultImageSymbol, Url>;
}

export enum DailyRefreshType {
  GOOGLE_PHOTOS = 'daily_refresh_google_photos',
  BACKDROP = 'daily_refresh_backdrop',
}

/**
 * |id| stores either a Backdrop collection id or a Google Photos album id.
 * |type| stores which type of daily refresh and type of id this is.
 */
export interface DailyRefreshState {
  id: string;
  type: DailyRefreshType;
}

export interface WallpaperState {
  backdrop: BackdropState;
  loading: LoadingState;
  local: LocalState;
  currentSelected: CurrentWallpaper|null;
  pendingSelected: DisplayableImage|null;
  dailyRefresh: DailyRefreshState|null;
  fullscreen: boolean;
  googlePhotos: GooglePhotosState;
}

export function emptyState(): WallpaperState {
  return {
    backdrop: {collections: null, images: {}},
    loading: {
      collections: true,
      images: {},
      local: {images: false, data: {[kDefaultImageSymbol]: false}},
      refreshWallpaper: false,
      selected: false,
      setImage: 0,
      googlePhotos: {
        enabled: false,
        albums: false,
        photos: false,
        photosByAlbumId: {},
      },
    },
    local: {images: null, data: {[kDefaultImageSymbol]: {url: ''}}},
    currentSelected: null,
    pendingSelected: null,
    dailyRefresh: null,
    fullscreen: false,
    googlePhotos: {
      enabled: undefined,
      albums: undefined,
      photos: undefined,
      photosByAlbumId: {},
      resumeTokens: {albums: null, photos: null, photosByAlbumId: {}},
    },
  };
}

==> chromium_111.0.5563.64.orig.tar.xz: chromium-111.0.5563.64/ash/webui/personalization_app/resources/js/wallpaper/wallpaper_state.ts <==
// Copyright 2021 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import {FilePath} from 'chrome://resources/mojo/mojo/public/mojom/base/file_path.mojom-webui.js';
import {Url} from 'chrome://resources/mojo/url/mojom/url.mojom-webui.js';

import {CurrentWallpaper, GooglePhotosAlbum, GooglePhotosEnablementState, GooglePhotosPhoto, WallpaperCollection, WallpaperImage} from '../personalization_app.mojom-webui.js';

import {DefaultImageSymbol, DisplayableImage, kDefaultImageSymbol} from './constants.js';

/**
 * Stores collections and images from backdrop server.
 * |images| is a mapping of collection id to the list of images.
 */
export interface BackdropState {
  collections: WallpaperCollection[]|null;
  images: Record<WallpaperCollection['id'], WallpaperImage[]|null>;
}

/**
 * Stores Google Photos state.
 * |enabled| is whether the user is allowed to access Google Photos. It is
 * undefined only until it has been initialized.
 * |albums| is the list of Google Photos owned albums. It is undefined only
 * until it has been initialized, then either null (in error state) or a valid
 * Array.
 * |albumsShared| is the list of Google Photos shared albums.
 * |photos| is the list of Google Photos photos. It is undefined only until it
 * has been initialized, then either null (in error state) or a valid Array.
 * |photosByAlbumId| is the list of Google Photos photos keyed by album id. The
 * list of photos for a given album id is undefined only until is has been
 * initialized, then either null (in error state) or a valid Array.
 */
export interface GooglePhotosState {
  enabled: GooglePhotosEnablementState|undefined;
  albums: GooglePhotosAlbum[]|null|undefined;
  albumsShared: GooglePhotosAlbum[]|null|undefined;
  photos: GooglePhotosPhoto[]|null|undefined;
  photosByAlbumId: Record<string, GooglePhotosPhoto[]|null|undefined>;
  resumeTokens: {
    albums: string|null,
    albumsShared: string|null,
    photos: string|null,
    photosByAlbumId: Record<string, string|null>,
  };
}

/**
 * Stores loading state of various components of the app.
 * |images| is a mapping of collection id to loading state.
 * |local| stores data just for local images on disk.
 * |local.data| stores a mapping of FilePath.path string to loading state.
 *
 * |selected| is a boolean representing the loading state of current wallpaper
 * information. This gets complicated when a user rapidly selects multiple
 * wallpaper images, or picks a new daily refresh wallpaper. This becomes
 * false when a new CurrentWallpaper object is received and the |setImage|
 * counter is at 0.
 *
 * |setImage| is a number representing the number of concurrent requests to set
 * current wallpaper information. This can be more than 1 in case a user rapidly
 * selects multiple wallpaper options.
 *
 * |googlePhotos| stores loading state of Google Photos data.
 */
export interface LoadingState {
  collections: boolean;
  images: Record<WallpaperCollection['id'], boolean>;
  local: {
    images: boolean,
    data: Record<FilePath['path']|DefaultImageSymbol, boolean>,
  };
  refreshWallpaper: boolean;
  selected: boolean;
  setImage: number;
  googlePhotos: {
    enabled: boolean,
    albums: boolean,
    albumsShared: boolean,
    photos: boolean,
    photosByAlbumId: Record<string, boolean>,
  };
}

/**
 * |images| stores the list of images on local disk. The image in index 0 may be
 * a special case for default image thumbnail.
 * |data| stores a mapping of image.path to a thumbnail data url. There is also
 * a special key to represent the default image thumbnail.
 */
export interface LocalState {
  images: Array<FilePath|DefaultImageSymbol>|null;
  data: Record<FilePath['path']|DefaultImageSymbol, Url>;
}

export enum DailyRefreshType {
  GOOGLE_PHOTOS = 'daily_refresh_google_photos',
  BACKDROP = 'daily_refresh_backdrop',
}

/**
 * |id| stores either a Backdrop collection id or a Google Photos album id.
 * |type| stores which type of daily refresh and type of id this is.
 */
export interface DailyRefreshState {
  id: string;
  type: DailyRefreshType;
}

export interface WallpaperState {
  backdrop: BackdropState;
  loading: LoadingState;
  local: LocalState;
  currentSelected: CurrentWallpaper|null;
  pendingSelected: DisplayableImage|null;
  dailyRefresh: DailyRefreshState|null;
  fullscreen: boolean;
  googlePhotos: GooglePhotosState;
}

export function emptyState(): WallpaperState {
  return {
    backdrop: {collections: null, images: {}},
    loading: {
      collections: true,
      images: {},
      local: {images: false, data: {[kDefaultImageSymbol]: false}},
      refreshWallpaper: false,
      selected: false,
      setImage: 0,
      googlePhotos: {
        enabled: false,
        albums: false,
        albumsShared: false,
        photos: false,
        photosByAlbumId: {},
      },
    },
    local: {images: null, data: {[kDefaultImageSymbol]: {url: ''}}},
    currentSelected: null,
    pendingSelected: null,
    dailyRefresh: null,
    fullscreen: false,
    googlePhotos: {
      enabled: undefined,
      albums: undefined,
      albumsShared: undefined,
      photos: undefined,
      photosByAlbumId: {},
      resumeTokens:
          {albums: null, albumsShared: null, photos: null, photosByAlbumId: {}},
    },
  };
}
